@@ -18,7 +18,6 @@
 # Contact information: Zmanda Inc, 505 N Mathlida Ave, Suite 120
 # Sunnyvale, CA 94085, USA, or: http://www.zmanda.com
 #
-#
 
 # This is meant to be invoked by xinetd.
 # It expects two arguments on stdin
@@ -60,11 +59,10 @@ my $tmp_directory;
 my $action;
 my $params;
 my $MYSQLHOTCOPY="mysqlhotcopy";
-my $VERSION="1.9";
+my $VERSION="1.8";
 my $logDir = "/var/log/mysql-zrm";
 my $logFile = "$logDir/socket-server.log";
 my $snapshotInstallPath = "/usr/share/mysql-zrm/plugins";
-my $compress = "";
 
 open LOG, ">$logFile" or die "Unable to create log file";
 $SIG{'PIPE'} = sub { &printAndDie( "pipe broke\n" ); };
@@ -72,14 +70,6 @@ $SIG{'PIPE'} = sub { &printAndDie( "pipe broke\n" ); };
 # This will only allow and a-z A-Z 0-9 _ - / . = " ' ; + * and space.
 # Modify this if any other characters are to be allowed.
 sub checkIfTainted(){
-	# The only field where semicolon can exist is in password
-	# So blank out the password while checking for existence of semicolon
-	my $x = $_[0];
-	$x=~s/\s+--password=("[^"]*")\s+/ --password="" /;
-	if( $x =~ /;/ ){
-		&printAndDie("Bad data in $_[0]\n");
-	}
-	
         if( $_[0] =~ /^([-\*\w\/"\'.\:;\+\s=\^\$]+)$/) {
                 return $1;
         }else{
@@ -114,7 +104,7 @@ sub getInputs()
 	if( $x ne $VERSION ){
 		&printAndDie( "Version of remote copy plugin does not match\n" );
 	}
-	for( my $i = 0; $i < 5; $i++ ){
+	for( my $i = 0; $i < 4; $i++ ){
 		$x = <STDIN>;
 		push @inp, $x;	
 	}
@@ -123,12 +113,6 @@ sub getInputs()
 	$params = &checkIfTainted($inp[1]);
 	$TMPDIR = &checkIfTainted($inp[2]);
 	$MYSQL_BINPATH = &checkIfTainted($inp[3]);
-	if( $inp[4] ne "" ){
-		$compress = &checkIfTainted($inp[4]);
-	}
-	if( ! -d $MYSQL_BINPATH || ! -f "$MYSQL_BINPATH/$MYSQLHOTCOPY" ){
-		&printAndDie( "mysqlhotcopy not found\n" );
-	}
 }
 
 sub doHotCopy()
@@ -154,7 +138,7 @@ sub writeTarStream()
                 $fileList = " -T $tmpFile";
         }
 
-	unless(open( TAR_H, "$TAR --same-owner $compress -cphsC $_[0] $fileList 2>/dev/null|" ) ){
+	unless(open( TAR_H, "$TAR --same-owner -cphszC $_[0] $fileList 2>/dev/null|" ) ){
 		&printandDie( "tar failed $!\n" );
 	}
 	binmode( TAR_H );
@@ -174,7 +158,7 @@ sub writeTarStream()
 #$_[0] dirname to strea the data to
 sub readTarStream()
 {
-	unless(open( TAR_H, "|$TAR --same-owner $compress -xphsC $_[0] 2>/dev/null" ) ){
+	unless(open( TAR_H, "|$TAR --same-owner -xphszC $_[0] 2>/dev/null" ) ){
 		&printandDie( "tar failed $!\n" );
 	}
 
@@ -279,12 +263,7 @@ sub doCreateLink()
 	for( $i = 0; $i < $num; $i += 2 ){
 		my $p = &readOneLine();
 		my $link = &readOneLine();
-		eval { mkpath( $p, 0, 0700 ) };
-		if ($@) {
-			&printToServer( "ERROR", "Unable to create directory $p, $@" );
-			&printAndDie( "Unable to create directory $p, $@ \n" );
-		}
-
+		mkpath( $p, 0, 0700 );
 		my $cmd = "ln -s $link";
 		my $r = system( $cmd );
 		if( $r != 0 ){
@@ -396,10 +375,7 @@ if( $action eq "copy from" ){
 	}
 	&doCopyBetween();
 }elsif( $action eq "copy to" ){
-	my $s = $params;
-	$s =~ s/^"//;
-	$s =~ s/"$//;
-	if( ! -d $s ){
+	if( ! -d $params ){
 		&printAndDie( "$params not found\n" );
 	}
 	&readTarStream( $params );
